*	A. Prepare country inputs 

* First set up the dataset for a time series
capture cd "./1. Input Files"
import delimited "countries.csv", varnames(1) clear
forval i = 2000/2015 { 
	gen y`i' = .
}
reshape long y, i(whoname) j(year)
drop y
order year
replace whoname = "Cote d'Ivoire" if whoname == "CÈte d'Ivoire"
replace region_mid = "Africa Central Meningitis" if iso3 == "COD"
gen men_belt = 0
replace men_belt = 1 if region_mid == "Africa Central Meningitis"
order year iso3
save "countries_time_series.dta", replace

* Prepare inputs

* Prepare World Bank income categories for each year. 
import excel "OGHIST.xls", sheet("Country Analytical History") ///
cellrange(A12:AD226) clear
rename A iso3
rename B whoname
drop C D E F G H I J K L M N O
local i = 2000
foreach v in P Q R S T U V W X Y Z AA AB AC AD {
	rename `v' y`i'
	local i = `i' + 1
}
gen y2015 = ""
reshape long y, i(whoname) j(year)
rename y wb_cat
replace wb_cat = "Lower" if wb_cat == "L"
replace wb_cat = "Lower Middle" if wb_cat == "LM"
replace wb_cat = "Upper Middle" if wb_cat == "UM"
replace wb_cat = "High" if wb_cat == "H"
replace wb_cat = "" if wb_cat == ".."
gen wb_cat_src = ""
replace wb_cat_src = "World Bank" if wb_cat != ""
replace wb_cat_src = "Flat trend" if wb_cat == ""
by whoname: replace wb_cat = wb_cat[_n-1] if missing(wb_cat) & year == 2015
forval i = 1/16 {
	by whoname: replace wb_cat = wb_cat[_n+`i'] if missing(wb_cat)
}
replace iso3 = "AND" if whoname == "Andorra"
replace iso3 = "COD" if whoname == "Congo, Dem. Rep."
replace iso3 = "ROU" if whoname == "Romania"
replace iso3 = "TLS" if whoname == "Timor-Leste"
local new_obs = _N + (3*16)
set obs `new_obs'
forval i = 3441/3456 {
	replace whoname = "Cook Islands" if _n == `i'
	replace iso3 = "COK" if _n == `i'
	replace wb_cat = "NA" if _n == `i'
	replace year = `i' - 1441 if _n == `i'
}
forval i = 3457/3472 {
	replace whoname = "Nauru" if _n == `i'
	replace iso3 = "NRU" if _n == `i'
	replace wb_cat = "NA" if _n == `i'
	replace year = `i' - 1457 if _n == `i'
}
forval i = 3473/3488 {
	replace whoname = "Niue" if _n == `i'
	replace iso3 = "NIU" if _n == `i'
	replace wb_cat = "NA" if _n == `i'
	replace year = `i' - 1473 if _n == `i'
}
save "wb_cat.dta", replace

* Prepare child mortality categories.
import excel "RatesDeaths_AllIndicators.xlsx", sheet("Rates and Deaths") ///
cellrange(A7:OI592) firstrow clear
drop if Uncertaintybounds != "Median"
drop Uncertaintybounds
rename CountryName whoname
rename ISOCode iso3
forval i = 1950/1999 {
		drop *`i'
}
reshape long U5MR IMR NMR UnderfiveDeaths InfantDeaths NeonatalDeaths, ///
i(whoname) j(year)
rename U5MR u5mr
rename IMR imr
rename NMR nmr
rename UnderfiveDeaths u5_deaths
rename InfantDeaths infant_deaths
rename NeonatalDeaths neonatal_deaths
foreach var in u5mr imr nmr u5_deaths infant_deaths neonatal_deaths {
	gen `var'_src = "UN IGME, 2015 update"
}
gen mortality_stratum = "1.Very Low" if  u5mr < 30
replace mortality_stratum = "2.Medium" if  u5mr >= 30 & u5mr < 75
replace mortality_stratum = "3.High" if  u5mr >= 75 & u5mr < 150
replace mortality_stratum = "4.Very High" if u5mr >= 150
order year whoname iso3 u5mr u5mr_src imr imr_src nmr nmr_src u5_deaths ///
u5_deaths_src infant_deaths infant_deaths_src ///
neonatal_deaths neonatal_deaths_src mortality_stratum
save "mortality.dta", replace

* Prepare under five population estimates.
import excel "WPP2015_POP_F15_1_ANNUAL_POPULATION_BY_AGE_BOTH_SEXES.xls", ///
sheet("ESTIMATES") cellrange(A942:AB15923) clear
keep C F G // Add additional column names to get other age groups
rename C whoname
rename F year
rename G u5_pop
drop if year < 2000
replace u5_pop = u5_pop * 1000
sort whoname year
gen u5_pop_src = "UN WPP, 2015 update"
replace whoname = "Cape Verde" if whoname == "Cabo Verde"
replace whoname = "Cote d'Ivoire" if whoname == "Côte d'Ivoire"
replace whoname = "Democratic People's Republic of Korea" if whoname == ///
"Dem. People's Republic of Korea"
replace whoname = "Micronesia (Federated States of)" if whoname == ///
"Micronesia (Fed. States of)" 
replace whoname = "The former Yugoslav Republic of Macedonia" if whoname == ///
"TFYR Macedonia"
format u5_pop %10.0f
save "u5_pop.dta", replace

* Prepare Hib vaccine coverage estimates
import excel "coverage_estimates_series.xls", sheet("Hib3") firstrow clear
rename ISO_code iso3
rename Cname whoname
rename Vaccine vaccine
local i = 2015
foreach v in E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD {
	rename `v' y`i'
	local i = `i' - 1
}
drop AE AF AG AH AI AJ AK AL AM AN
reshape long y, i(iso3) j(year)
rename y hib3
gen hib3_src = "WHO/UNICEF, 2016 update"
replace hib3 = hib3/100
replace hib3 = 0 if hib3 == .
gen years_after_hib = .
replace years_after_hib = 1 if hib3 > 0
replace years_after_hib = 0 if years_after_hib != 1
sort iso3 year
by iso3: replace years_after_hib = years_after_hib[_n - 1] + 1 if ///
years_after_hib > 0
drop if year < 2000
drop vaccine Region
save "hib3.dta", replace

* Prepare DTP3 vaccine coverage estiamtes
import excel "coverage_estimates_series.xls", sheet("DTP3") firstrow clear
rename ISO_code iso3
rename Cname whoname
rename Vaccine vaccine
local i = 2015
foreach v in E F G H I J K L M N O P Q R S T {
	rename `v' y`i'
	local i = `i' - 1
}
keep iso3 whoname vaccine y*
reshape long y, i(iso3) j(year)
rename y dtp3
gen dtp3_src = "WHO/UNICEF, 2016 update"
replace dtp3 = 0 if dtp3 == .
replace dtp3 = dtp3/100
forval i = 2000/2010 {
	quietly sum dtp3 if iso3 == "SDN" & year == `i'
	replace dtp3 = r(mean) if iso3 == "SSD" & year == `i'
}
drop vaccine
save "dtp3.dta", replace

* Prepare PCV coverage estimates
import delimited "pcv_coverage_2015.csv", clear
foreach pcv in pcv pcv7 pcv10 pcv13 {
	replace `pcv' = `pcv'/100
}
save "pcv.dta", replace

* ST replacement
import delimited "pcv_st_replacement.csv", clear
rename year years_after_pcv
save "pcv_replacement.dta", replace

* PCV serotype coverage
import delimited "pcv_st_coverage.csv", clear
save "pcv_coverage.dta", replace

* Proportion of pneumococcal disease
import excel "Spn disease distribution_20161213.xlsx", sheet("IPD cases summary") cellrange(A1:H6) firstrow clear
replace region = "Oceania" if region == "Western Pacific"
replace region = "Northern America" if region == "Americas"
expand 2 if region == "Northern America"
replace region = "Latin America and the Carribean" in 6
gen cases_1_11 = cases_2_3 + cases_4_5 + cases_6_11
drop cases_2_3 cases_4_5 cases_6_11
rename cases* ipd_cases*
order region ipd_cases_1_11
save "spn_ipd_cases.dta", replace

import excel "Spn disease distribution_20161213.xlsx", sheet("IPD deaths summary") cellrange(A1:H6) firstrow clear
replace region = "Oceania" if region == "Western Pacific"
replace region = "Northern America" if region == "Americas"
expand 2 if region == "Northern America"
replace region = "Latin America and the Carribean" in 6
gen deaths_1_11 = deaths_2_3 + deaths_4_5 + deaths_6_11
drop deaths_2_3 deaths_4_5 deaths_6_11
rename deaths* ipd_deaths*
order region ipd_deaths_1_11
save "spn_ipd_deaths.dta", replace

import excel "Spn disease distribution_20161213.xlsx", sheet("Meningitis cases summary") cellrange(A1:H6) firstrow clear
replace region = "Oceania" if region == "Western Pacific"
replace region = "Northern America" if region == "Americas"
expand 2 if region == "Northern America"
replace region = "Latin America and the Carribean" in 6
gen cases_1_11 = cases_2_3 + cases_4_5 + cases_6_11
drop cases_2_3 cases_4_5 cases_6_11
rename cases* men_cases*
order region men_cases_1_11
save "spn_men_cases.dta", replace

import excel "Spn disease distribution_20161213.xlsx", sheet("Meningitis deaths summary") cellrange(A1:H6) firstrow clear
replace region = "Oceania" if region == "Western Pacific"
replace region = "Northern America" if region == "Americas"
expand 2 if region == "Northern America"
replace region = "Latin America and the Carribean" in 6
gen deaths_1_11 = deaths_2_3 + deaths_4_5 + deaths_6_11
drop deaths_2_3 deaths_4_5 deaths_6_11
rename deaths* men_deaths*
order region men_deaths_1_11
save "spn_men_deaths.dta", replace

* Prepare meningococcal vaccine coverage estimates
import excel "mening_vaccine.xlsx", sheet("Serogroup summarized") ///
cellrange(A3:O9) clear
rename A region
rename B a_men_sg
rename C b_men_sg
rename D c_men_sg
rename E w135_men_sg
rename F x_men_sg
rename G y_men_sg
rename H other_men_sg
rename I a_men_sg_epi
rename J b_men_sg_epi
rename K c_men_sg_epi
rename L w135_men_sg_epi
rename M x_men_sg_epi
rename N y_men_sg_epi
rename O other_men_sg_epi
foreach serogroup in a_men_sg b_men_sg c_men_sg w135_men_sg x_men_sg ///
y_men_sg other_men_sg {
	replace `serogroup' = `serogroup'/100
	replace `serogroup'_epi = `serogroup'_epi/100
}
gen men_belt = 0
replace men_belt = 1 if region == "Africa Belt"
replace region = "Africa" if region == "Africa Belt" | ///
region == "Africa non-Belt"
replace region = "Latin America and the Carribean" if region == "Latin America"
gen men_sg_src = "Unpublished IVAC analysis"
save "mening_serogroup.dta", replace
import excel "mening_vaccine.xlsx", sheet("Vaccine") firstrow clear
rename country whoname
rename C year
rename D men_vx_sg
rename vaccineuseassumedaftermassc men_vx_sg_adj
replace men_vx_sg = "" if men_vx_sg == "0"
replace men_vx_sg_adj = "" if men_vx_sg_adj == "0"
gen men_vx_sg_src = ""
replace men_vx_sg_src = "Ali, et al., 2014/PATH MVP" if men_vx_sg != ""
replace men_vx_sg_src = "Assumed impact of MenAfriVac" if ///
men_vx_sg_adj == "a" & men_vx_sg == ""
save "mening_vx.dta", replace 

* Prepare HIV prevalence estimates 
import excel "HIV2014Estimates_HIV_20Oct2015.xlsx", sheet("Sheet2") ///
cellrange(A3:N2460) clear
drop  C D F G H I J K L M N 
rename A whoname
rename B year
rename E hiv_prev
replace hiv_prev = hiv_prev/100
sort whoname year
gen hiv_prev_src = "UNAIDS" 
order year whoname 
sort whoname year
drop if whoname == ""
replace whoname = "Bolivia (Plurinational State of)" if whoname == "Bolivia"
replace whoname = "Cote d'Ivoire" if whoname ==  "Cote dIvoire"
replace whoname = "Democratic People's Republic of Korea" if whoname ==  ///
"Democratic People Republic of Korea"
replace whoname = "Lao People's Democratic Republic" if whoname == ///
"Lao People Democratic Republic"
replace whoname = "Sao Tome and Principe" if whoname == ///
"São Tomé and Príncipe"
replace whoname = "Venezuela (Bolivarian Republic of)" if whoname == "Venezuela"
save "hiv.dta", replace

* Prepare ART Utilization estimates 
import excel "hiv_art.xlsx", sheet("Sheet1") cellrange(A1:C35) firstrow clear
gen year = 2015
rename source art_source
order year whoname art art_source
save "hiv_art.dta", replace

* Prepare access to care estimates
import excel ///
"Pneumonia_careseeking_treatment_indicators_June 2015_UNICEF_1582c25.xlsx", ///
sheet("Care seeking for suspected pneu") cellrange(A8:O390) firstrow clear
drop  Sex F Residence H Wealthquintile J K L M O
drop if _n == 1
rename Total access_to_care
replace access_to_care = access_to_care/100
rename ISOCode iso3
rename Countriesandareas whoname
rename Source access_to_care_src
gen year_start = substr(Yearsofdatacollection, 1,4)
gen year_end = substr(Yearsofdatacollection, -4,.)
destring year_start, replace
destring year_end, replace
drop Yearsofdatacollection
replace year_end = . if year_end == year_start
gen diff = year_end - year_start if year_end != . 
forval i = 1/5 {
	expand `i' + 1 if diff == `i'
}
sort whoname year_start
order year_start year_end iso3 whoname access_to_care access_to_care_src
by whoname year_start: gen count = _n if diff != .
replace year_start = year_start + count - 1 if diff != . 
rename year_start year
drop count year_end
sort iso3 year access_to_care
quietly by iso3 year: gen dup = cond(_N == 1, 0, _n)
sort whoname year dup
by whoname year: replace access_to_care = (access_to_care+access_to_care[_n+1])/2 if dup == 1
by whoname year: replace access_to_care_src = "Average of " + access_to_care_src + " and " + access_to_care_src[_n+1] if dup == 1
drop if dup == 2
drop dup
sort whoname year
rename diff multi_atc
replace multi_atc = 1 if multi_atc != . 
drop if iso3 == "X0X" | year < 2000 | iso3 == "PSE"
save "access.dta", replace

* Prepare morbidity envelopes 
foreach case in "" "severe_" {
	forvalues i = 2000(15)2015 {
		import excel "Incidence of `case'pneumonia in `i'.xlsx", sheet("table1_`i'") ///
		firstrow clear
		foreach v in incidence episodes incidence_hiv episodes_hiv episodes_attr_hiv {
			split `v', p("(" "-" ")")
		}
		drop incidence episodes incidence_hiv episodes_hiv episodes_attr_hiv
		foreach v in incidence episodes incidence_hiv episodes_hiv episodes_attr_hiv {
			rename `v'1 `v'_`case'`i'
			rename `v'2 `v'_`case'`i'_lb
			rename `v'3 `v'_`case'`i'_ub
		}
		destring incidence_`case'`i' incidence_`case'`i'_lb incidence_`case'`i'_ub episodes_`case'`i' ///
		episodes_`case'`i'_lb episodes_`case'`i'_ub incidence_hiv_`case'`i' incidence_hiv_`case'`i'_lb ///
		incidence_hiv_`case'`i'_ub episodes_hiv_`case'`i' episodes_hiv_`case'`i'_lb ///
		episodes_hiv_`case'`i'_ub episodes_attr_hiv_`case'`i' episodes_attr_hiv_`case'`i'_lb ///
		episodes_attr_hiv_`case'`i'_ub, replace
		gen year = `i'
		rename country whoname
		replace whoname = "Bolivia (Plurinational State of)" if whoname == "Bolivia"
		replace whoname = "Democratic People's Republic of Korea" if ///
		whoname == "Dem. Peoples's Rep. of Korea"
		replace whoname = "Democratic Republic of the Congo" if ///
		whoname == "Dem. Rep. of the Congo"
		replace whoname = "Lao People's Democratic Republic" if ///
		whoname == "Lao People's Dem. Republic"
		replace whoname = "Libya" if whoname == "Libyan Arab Jamahiriya"
		replace whoname = "Micronesia (Federated States of)" if ///
		whoname == "Micronesia (Fed. States of)"
		replace whoname = "Saint Vincent and the Grenadines" if ///
		whoname == "Saint Vincent and Grenadines"
		replace whoname = "Venezuela (Bolivarian Republic of)" if ///
		whoname == "Venezuela"
		capture rename *severe* *sev*
		save "`i'_`case'incidence.dta", replace
	}
}
*

* Now bring everything together in one file

* Merge World Bank data
use "countries_time_series.dta", clear
merge 1:m iso3 year using "wb_cat.dta"
drop if _merge == 2
drop _merge

* Merge mortality data
merge 1:m iso3 year using "mortality.dta"
drop if _merge == 2
drop _merge

* Merge poopulation data
merge 1:m whoname year using "u5_pop.dta"
drop if _merge == 2
drop _merge 
replace u5_pop_src = "Estimated from live births, no data available" ///
if u5_pop == .

* Merge Hib vaccine covearge data
merge 1:m iso3 year using "hib3.dta", nogen
gen hib3_adj = hib3
replace hib3_adj = hib3 * (years_after_hib/2) if years_after_hib == 1

* Merge DTP3 coverage data 
merge 1:m iso3 year using "dtp3.dta", nogen

* Merge PCV coverage data 
merge 1:m iso3 year using "pcv.dta", nogen
gen years_after_pcv = .
replace years_after_pcv = 1 if pcv > 0
replace years_after_pcv = 0 if years_after_pcv != 1
bysort iso3: replace years_after_pcv = years_after_pcv[_n - 1] + 1 if ///
years_after_pcv > 0
gen pcv_adj = pcv 
replace pcv_adj = pcv_adj * (years_after_pcv/5) if years_after_pcv <= 5
foreach form in "7" "10" "13" {
	gen pcv`form'_adj = pcv`form'
	replace pcv`form'_adj = pcv`form'_adj * (years_after_pcv/5) if ///
	years_after_pcv <= 5
}
*

* PCV serotype coverage
merge m:m region using "pcv_coverage.dta"
drop _merge

* Merge ST replacement
merge m:m years_after_pcv using "pcv_replacement.dta"
drop _merge
sort whoname year
replace vt_rr = . if pcv7_adj == 0
replace nvt_rr = . if pcv7_adj == 0
replace all_type_rr = . if pcv7_adj == 0
sort iso3 year
by iso3: replace vt_rr = vt_rr[_n-1] if pcv7_adj > 0 & vt_rr == .
by iso3: replace nvt_rr = nvt_rr[_n-1] if pcv7_adj > 0 & nvt_rr == .
by iso3: replace all_type_rr = all_type_rr[_n-1] if pcv7_adj > 0 & ///
all_type_rr == .
gen st_replacement_src = "Feiken, et al. 2013" if vt_rr != .
foreach rr in vt_rr nvt_rr all_type_rr {
	replace st_replacement_src = "Assume no serotype replacement" if `rr' == .
	replace `rr' = 1 if `rr' == .
}
*

* Merge proportion of pneumococcal disease
merge m:m region using "spn_ipd_cases.dta"
drop _merge
merge m:m region using "spn_ipd_deaths.dta"
drop _merge
merge m:m region using "spn_men_cases.dta"
drop _merge
merge m:m region using "spn_men_deaths.dta"
drop _merge

* Merge mening conjugate vaccine formulation and coverage data
merge 1:m iso3 year using "mening_vx.dta"
drop if _merge == 2
drop _merge
gen men_vx = . 
replace coverage = coverage/100
replace men_vx = coverage
gen years_after_men = .
replace years_after_men = 1 if men_vx_sg_adj != ""
replace years_after_men = 0 if years_after_men != 1
bysort iso3: replace years_after_men = years_after_men[_n - 1] + 1 if ///
years_after_men > 0 & iso3 != "GBR"
forval i = 2001/2015 { 
	replace years_after_men = years_after_men[_n - 1] + 1 if year == `i' & ///
	iso3 == "GBR"
}
replace men_vx = dtp3 * (years_after_men/5) if years_after_men <= 5 & ///
men_vx == . & years_after_men != 0 & coverage == .
replace men_vx = dtp3 if years_after_men > 5 & years_after_men != 0 & ///
coverage == .
replace men_vx = 0 if men_vx == .
drop coverage
replace men_vx = 0.95 if men_vx_sg_adj == "a"

* Merge death envelopes
merge 1:1 iso3 year using "undo_posthoc_global all.dta"
drop level  neo7 neo9 rneo7 rneo9 fneo7 fneo9 p_pne p_men ///
neometh fufive7 fufive9 whocode level whoreg6 nnd ufive7 ufive9 rufive7 ///
rufive9 fufive7 fufive9 neometh n_inj p_inj mr_inj n_mal p_mal mr_mal n_oth ///
p_oth mr_oth n_dia p_dia mr_dia n_neo p_neo mr_neo n_con p_con mr_con ///
ufive9_unadj fufive9_unadj rufive9_unadj ufive7_unadj fufive7_unadj ///
rufive7_unadj _merge
rename livebirths live_births
rename pnmeth meth
rename post7 pn_meningitis_a
rename post9 pn_pneumonia_a
rename rpost7 pn_meningitis_a_rate
rename rpost9 pn_pneumonia_a_rate
rename n_pne pn_pneumonia
rename n_men pn_meningitis
rename mr_men pn_meningitis_rate
rename mr_pne pn_pneumonia_rate
rename pnd post_neonatal_deaths
rename fpost7 prop_meningitis_after_ph_adj
rename fpost9 prop_pneumonia_after_ph_adj
replace pn_pneumonia = pn_pneumonia_a if meth == "good vr" | ///
meth == "vrmcm" | meth == "other"
replace pn_meningitis = pn_meningitis_a if meth == "good vr" | ///
meth == "vrmcm" | meth == "other"
replace pn_pneumonia_rate = pn_pneumonia_a_rate if meth == "good vr" | ///
meth == "vrmcm" | meth == "other"
replace pn_meningitis_rate = pn_meningitis_a_rate if meth == "good vr" | ///
meth == "vrmcm" | meth == "other"
replace u5_pop = 5 * live_births if u5_pop == .
gen pop_1_59 = u5_pop * (59/60)

* Merge HIV data
merge 1:m whoname year using "hiv.dta"
sort iso3 year
replace hiv_prev_src = "No data; assume 0" if hiv_prev == . & year < 2015
replace hiv_prev = 0 if hiv_prev == . & year < 2015
sort iso3 year
by iso3: ipolate hiv_prev year, gen(hiv_prev_ipolate) epolate
replace hiv_prev_src = "Interpolated" if year > 2014
replace hiv_prev_ipolate = 0 if hiv_prev_ipolate < 0
drop hiv_prev
rename hiv_prev_ipolate hiv_prev
merge 1:1 whoname year using "hiv_art.dta", nogen
replace art = 0 if art == . & year == 2015
gen hiv_cases = (hiv_prev * u5_pop) if year < 2015
replace hiv_cases = (hiv_prev * u5_pop) - art if year == 2015
replace hiv_prev = (hiv_cases/u5_pop) if art != . 
replace hiv_prev = 0 if hiv_prev < 0
rename hiv_cases hiv_cases_no_art
drop _merge

* Generate indexes and HIV prevalence by index for later use
gen index_0 = whoname + mortality_stratum
gen index_1 = region_sub + mortality_stratum
gen index_2 = region_mid + mortality_stratum
gen index_3 = region + mortality_stratum
gen index_4 = mortality_stratum

forval i = 0/4 {
	gen hiv_prev_index_`i' = . 
}
*

forval y = 2000/2015 {
	forval i = 0/4 {
		quietly levelsof index_`i', local(index)
		foreach index in `index' {
			quietly sum u5_pop if index_`i' == "`index'" & year == `y'
			local pop = r(sum)
			quietly sum hiv_cases if index_`i' == "`index'" & year == `y'
			local hiv_cases = r(sum)
			replace hiv_prev_index_`i' = `hiv_cases' / `pop' if ///
			index_`i' == "`index'" & year == `y'
		}
	}
}
*

* Merge access to care data (and interpolate/extrapolate for missing data). 
merge 1:m iso3 year using "access.dta"
drop if year < 2000 | iso3 == "PSE" | iso3 == "X0X"
drop _merge
sort iso3 year
by iso3: egen atc = count(access_to_care)
gen low_count = 1 if mortality_stratum=="1.Very Low"
by iso3: egen low = count(low_count)
gen u5mr_trans = (u5mr)^(1/4)

* No access to care estimates
quietly glm access_to_care u5mr_trans, ///
link(logit) family(binomial) robust cluster(whoname)
predict y
replace access_to_care_src = "MLR estimate based on U5MR" if atc == 0 & ///
mortality_stratum != "1.Very Low" & low == 0
replace access_to_care = y if atc == 0 & mortality_stratum != "1.Very Low" & ///
low == 0
drop y

* Low U5 mortality (assume 100%)
replace access_to_care_src = "Assume 1 for low mortality settings" if ///
mortality_stratum == "1.Very Low" & atc == 0 
replace access_to_care = 1 if mortality_stratum == "1.Very Low" & atc == 0

* Interpolate for those with 2 or more non-consecutive access to care estimates 
bysort iso3: ipolate access_to_care year if atc >= 2 , ///
generate(access_to_care_iepolate) epolate 
bysort iso3: ipolate access_to_care year if atc >= 2 , ///
generate(access_to_care_ipolate)  
by iso3: egen no_extrap = mean(multi_atc)
replace access_to_care = access_to_care_iepolate if access_to_care == . & ///
access_to_care_iepolate != . & no_extrap != 1
replace access_to_care = access_to_care_ipolate if access_to_care == . & ///
access_to_care_ipolate != . & no_extrap == 1
replace access_to_care_src = "Interpolated/Extrapolated" if access_to_care != . & ///
access_to_care_src == ""

* Recenter and apply regression coefficients for those with one estimate.
by iso3: gen counter = _n
gen center = .
by iso3: replace center = 1 if access_to_care != . & access_to_care[_n-1] == . & counter != 1
by iso3: replace center = 1 if access_to_care != . & access_to_care[_n+1] == . & counter != 16
gen years_from_center = 0 if center == 1
by iso3: replace years_from_center = 1 + years_from_center[_n-1] if years_from_center == . & years_from_center[_n-1] != . 
replace years_from_center = . if access_to_care_src != "" 
replace years_from_center = 0 if center == 1
forval i = 0/15 {
	by iso3: replace years_from_center = 1 + years_from_center[_n+1] if years_from_center == . & years_from_center[_n+1] == `i' 
}
gen diff_from_center = . 
gen center_logit = logit(access_to_care) if center == 1
replace center_logit = logit(.999999999999) if center == 1 & access_to_care == 1
gen intercept = center_logit 
forval i = 1/15 {
	by iso3: replace diff_from_center = u5mr_trans - u5mr_trans[_n-`i'] if years_from_center == `i' & years_from_center[_n-1] < years_from_center & diff_from_center == . & access_to_care == .
	by iso3: replace intercept = intercept[_n-`i'] if years_from_center == `i' & years_from_center[_n-1] < years_from_center & intercept == . & access_to_care == .
	by iso3: replace diff_from_center = u5mr_trans - u5mr_trans[_n+`i'] if years_from_center == `i' & years_from_center[_n+1] < years_from_center & diff_from_center == . & access_to_care == .
	by iso3: replace intercept = intercept[_n+`i'] if years_from_center == `i' & years_from_center[_n+1] < years_from_center & intercept == . & access_to_care == .
}
*
gen access_to_care_reg = invlogit(intercept+(diff_from_center * _b[u5mr_trans]))
replace access_to_care_src = "Applied regression-based trend using U5MR to existing estimates" if access_to_care == . & access_to_care_reg != . 
replace access_to_care = access_to_care_reg if access_to_care == . & access_to_care_reg != . 
drop atc low_count low u5mr_trans access_to_care_ipolate counter center ///
years_from_center diff_from_center center_logit intercept access_to_care_reg ///
access_to_care_iepolate multi_atc no_extrap
replace access_to_care = 1 if access_to_care > 1

* Merge with pneumonia case estimates
merge 1:1 whoname year using "2000_incidence.dta", nogen
merge 1:1 whoname year using "2015_incidence.dta", nogen
merge 1:1 whoname year using "2000_severe_incidence.dta", nogen
merge 1:1 whoname year using "2015_severe_incidence.dta", nogen

foreach measure in "incidence" "episodes" "incidence_hiv" "episodes_hiv" ///
"episodes_attr_hiv" "incidence_sev" "episodes_sev" "incidence_hiv_sev" ///
"episodes_hiv_sev" "episodes_attr_hiv_sev" {
	replace `measure'_2000 = `measure'_2015 if year == 2015
	replace `measure'_2000_lb = `measure'_2015_lb if year == 2015
	replace `measure'_2000_ub = `measure'_2015_ub if year == 2015
}
drop incidence_2015 incidence_2015_lb incidence_2015_ub episodes_2015 ///
episodes_2015_lb episodes_2015_ub incidence_hiv_2015 incidence_hiv_2015_lb ///
incidence_hiv_2015_ub episodes_hiv_2015 episodes_hiv_2015_lb ///
episodes_hiv_2015_ub episodes_attr_hiv_2015 episodes_attr_hiv_2015_lb ///
episodes_attr_hiv_2015_ub incidence_sev_2015 incidence_sev_2015_lb ///
incidence_sev_2015_ub episodes_sev_2015 episodes_sev_2015_lb ///
episodes_sev_2015_ub incidence_hiv_sev_2015 incidence_hiv_sev_2015_lb ///
incidence_hiv_sev_2015_ub episodes_hiv_sev_2015 episodes_hiv_sev_2015_lb ///
episodes_hiv_sev_2015_ub episodes_attr_hiv_sev_2015 ///
episodes_attr_hiv_sev_2015_lb episodes_attr_hiv_sev_2015_ub
foreach measure in "incidence" "episodes" "incidence_hiv" "episodes_hiv" ///
"episodes_attr_hiv" "incidence_sev" "episodes_sev" "incidence_hiv_sev" ///
"episodes_hiv_sev" "episodes_attr_hiv_sev" {
	rename `measure'_2000 pna_`measure'
	rename `measure'_2000_lb pna_`measure'_lb
	rename `measure'_2000_ub pna_`measure'_ub
}
*

* merge meningitis epidemic
merge 1:1 iso3 year using "global 2015_national men epi.dta"
drop _merge country
rename meningitis_epi_source meningitis_epi_src
replace meningitis_epi_src = "No data, assume 0" if meningitis_epi == .
replace meningitis_epi = 0 if meningitis_epi == .
gen pn_meningitis_no_epi = pn_meningitis/(exp(0.425*meningitis_epi))
gen pn_meningitis_epi_deaths = pn_meningitis - pn_meningitis_no_epi 

* merge mening serogroup distribution. 
merge m:1 region men_belt using "mening_serogroup.dta"
drop _merge
sort whoname year

* A little cleaning up after bringing everything together.
erase "wb_cat.dta"
erase "mortality.dta"
erase "u5_pop.dta"
erase "hib3.dta"
erase "dtp3.dta"
erase "pcv.dta"
erase "pcv_replacement.dta"
erase "pcv_coverage.dta"
erase "mening_serogroup.dta"
erase "mening_vx.dta"
erase "access.dta"
erase "countries_time_series.dta"
erase "2000_incidence.dta"
erase "2015_incidence.dta"
erase "2000_severe_incidence.dta"
erase "2015_severe_incidence.dta"
erase "hiv_art.dta"

cd ".."

* HIV RR
global spn_hiv_rr = 40.96
global hib_hiv_rr = 7.38
global nm_hiv_rr = 9 // Cohen et al.

save "countries_time_series.dta", replace
